<%inherit file="base.html"/>
<%def name="head()">
<script src="/static/js/bootstrap-datepicker.js"></script>
<link rel="stylesheet" href="/static/js/datepicker.css"> 
<script>
function on_chtype(){
    var ctype = $("#card_type").val()
    if(parseInt(ctype) == 0){
        $("#product_id").parent().parent().show();
        $("#months").parent().parent().show();
        $("#times").parent().parent().show();
        $("#flows").parent().parent().show();
    }else if(parseInt(ctype) == 1){
        $("#product_id").parent().parent().hide();
        $("#months").parent().parent().hide();
        $("#times").parent().parent().hide();
        $("#flows").parent().parent().hide();
    }
}

function productCalc(){
    if(parseInt($("#card_type").val())==1){
        $("#fee_value").val('0.00');
        return false;
    }
    var product_id = $("#product_id").val();
    $.get("/card/calc?product_id="+product_id, {}, function (ev) {
        console.log(ev);
        if(ev.code==0){
            console.log(ev.data);
            $("#fee_value").val(ev.data.fee_value);
            $("#months").val(ev.data.months);
            $("#times").val(ev.data.times);
            $("#flows").val(ev.data.flows);
        }else{
            alert(ev.data);
        }
    }, "json");
}

$(document).ready(function(){
    $("#expire_date").datepicker();
    on_chtype();
    productCalc();
    $("#card_type").change(function(event){
        on_chtype();
        productCalc();
    })
    $("#product_id").change(function(event){
        productCalc();
    })
});
</script>
</%def>
<%def name="body()">
    <div class="panel panel-default">
    <div class="panel-heading"><span class="glyphicon glyphicon-th"></span> ${form.title}<a class="badge pull-right" href="javascript:history.go(-1);">返回</a></div>
        <div class="panel-body">
            % if msg:
            <div class="alert alert-warning">${msg}</div>
            % endif
            <form class="form-horizontal form-well" role="form" action="${form.action}" method="post">
            ${form.render_css()}
        </form>
    </div>
</div>
</%def>