<%inherit file="base.html"/>
<%namespace name="sidebar_ui" file="sidebar_ui.html"/>
<%def name="head()">
</%def>
<%def name="main()">
<div class="panel panel-default">
    <div class="panel-heading"><span class="glyphicon glyphicon-user"></span> ${form.title}</div>
        <div class="panel-body">
            % if msg:
            <p class="alert alert-warning">
            ${msg}
            </p>
            % endif
            <form class="form-horizontal" role="form" action="${form.action}" method="post">
            ${form.render_css()}
        </form>
    </div>
</div>
</%def>

<%def name="sidebar()">
    ${sidebar_ui.login_box()}
    ${sidebar_ui.service_box()}
    ${sidebar_ui.qrcode_box()}
</%def>